# CHANGELOG

This is a manually generated log to track changes to the repository for each release. 
Each section should include general headers such as **Implemented enhancements** 
and **Merged pull requests**. All closed issued and bug fixes should be 
represented by the pull requests that fixed them. Critical items to know are:

 - renamed commands
 - deprecated / removed commands
 - changed defaults
 - backward incompatible changes


## [master](https://github.com/snakemake/snakeface/tree/main) (master)
 - adding missing settings.yml to install directory (0.0.14)
 - adding MANIFEST.in file (0.0.13)
 - adding missing social auth libraries (0.0.12)
 - early release with snakeface notebooks (0.0.11)
 - skeleton release (0.0.0)
